summaryrefslogtreecommitdiffstats
path: root/sys/dev
diff options
context:
space:
mode:
authoradrian <adrian@FreeBSD.org>2011-05-26 16:55:44 +0000
committeradrian <adrian@FreeBSD.org>2011-05-26 16:55:44 +0000
commitc2b7c664f96463ea844a65b6b0d5789851aae0ff (patch)
tree0baf20306ce3382d0b80039429f49a5870afb18f /sys/dev
parent6b0df643e262d89eb3fc6211281b9435236d07c5 (diff)
downloadFreeBSD-src-c2b7c664f96463ea844a65b6b0d5789851aae0ff.zip
FreeBSD-src-c2b7c664f96463ea844a65b6b0d5789851aae0ff.tar.gz
Make sure only two chains are calibrated for the AR9287.
Diffstat (limited to 'sys/dev')
-rw-r--r--sys/dev/ath/ath_hal/ar5416/ar5416_cal.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/dev/ath/ath_hal/ar5416/ar5416_cal.c b/sys/dev/ath/ath_hal/ar5416/ar5416_cal.c
index ee61c30..1356c7d 100644
--- a/sys/dev/ath/ath_hal/ar5416/ar5416_cal.c
+++ b/sys/dev/ath/ath_hal/ar5416/ar5416_cal.c
@@ -594,8 +594,8 @@ ar5416LoadNF(struct ath_hal *ah, const struct ieee80211_channel *chan)
if (AR_SREV_KITE(ah)) {
/* Kite has only one chain */
chainmask = 0x9;
- } else if (AR_SREV_MERLIN(ah)) {
- /* Merlin has only two chains */
+ } else if (AR_SREV_MERLIN(ah) || AR_SREV_KIWI(ah)) {
+ /* Merlin/Kiwi has only two chains */
chainmask = 0x1B;
} else {
chainmask = 0x3F;
OpenPOWER on IntegriCloud